@@ -47,21 +47,23 @@ local baron    = require "common.baron"
 local love_shaders = require "love_shaders"
 local portrait = require "portrait"
 
-local agentPort = "dvaered/dv_military_m2.webp"
-local BBB1Port = "pirate/pirate4.webp"
-local BBB2Port = "pirate/pirate6.webp"
+local agentPort = "dvaered/dv_military_m2"
+local BBB1Port = "pirate/pirate4"
+local BBB2Port = "pirate/pirate6"
 local npc1img, npc1por = vni.generic()
 local npc2img, npc2por = vni.generic()
 local npc3img, npc3por = vni.generic()
 local npc4img, npc4por = vni.generic()
 
-local gangs = { _("Big Bang Band"), -- gang of Blue Belly Billy
-                _("Cringe Crew"),
-                _("Dilettante Daemons"),
-                _("The Fuel Drinkers"),
-                _("Flamethrower Gang"),
-                _("The Stabbers"),
-                _("The Warriors") }
+local gangs = {
+   _("Big Bang Band"), -- gang of Blue Belly Billy
+   _("Cringe Crew"),
+   _("Dilettante Daemons"),
+   _("The Fuel Drinkers"),
+   _("Flamethrower Gang"),
+   _("The Stabbers"),
+   _("The Warriors")
+}
 
 -- Forward declarations of functions
 local spawnGang, land_state1, land_state3
@@ -164,10 +166,10 @@ function enter()
          local targetF = faction.dynAdd( "Independent", "targets", _("Targets"), {clear_enemies=true, clear_allies=true} )
 
          -- Put the targets
-         local center = pp:pos()
-         local t1 = center + vec2.new(0,5000)
-         local t2 = center + vec2.new(-4000,-2000)
-         local t3 = center + vec2.new(4000,-2000)
+         local centre = pp:pos()
+         local t1 = centre + vec2.new(0,5000)
+         local t2 = centre + vec2.new(-4000,-2000)
+         local t3 = centre + vec2.new(4000,-2000)
          mem.pil1 = pilot.add("Llama", targetF, t1, _("Kill Me"))
          mem.pil2 = pilot.add("Llama", targetF, t2, _("Kill Me"))
          mem.pil3 = pilot.add("Llama", targetF, t3, _("Kill Me"))
@@ -334,7 +336,7 @@ The man on your right answers: "Certainly not, your Lordship."]]),
       vn.na(_([[The Dvaered colonel and you get promptly dismissed, and he talks with you on the way back.]]))
       local sol = vn.newCharacter( _("Colonel Okran"), { image=portrait.getFullPath(agentPort) } )
       sol(fmt.f(_([["Citizen, you apparently did a pretty good job, out there. I did not fully understand why the Baron Sauterfeldt did want you to get your hands on that… piece of… stuff, but what is certain is that we can now count on him for getting our second battleship."
-"You deserve your reward. Please receive {credits}."]]), {credits=fmt.credits(pay)}))
+"You deserve your reward. Please receive {credits}."]]), {credits="#g"..fmt.credits(pay).."#0"}))
       vn.menu{
          {_("Talk with Okran"), "talk"},
          {_("Leave Okran ASAP"), "shutup"},
@@ -413,7 +415,7 @@ end
 function biker2()
    vn.clear()
    vn.scene()
-   local biker = vn.newCharacter( _("Hyena Biker"), { npc2img } )
+   local biker = vn.newCharacter( _("Hyena Biker"), { image=npc2img } )
    vn.transition()
    biker(_([["You came for the festival? What gang do you belong to? You don't wear any gang jacket."]]))
    vn.done()
@@ -422,7 +424,7 @@ end
 function biker3()
    vn.clear()
    vn.scene()
-   local biker = vn.newCharacter( _("Hyena Biker"), { npc3img } )
+   local biker = vn.newCharacter( _("Hyena Biker"), { image=npc3img } )
    vn.transition()
    biker(_([["Of course, we are gangs! We make tons of totally criminal stuff! One day, I even parked my Hyena at a spot reserved for delivery ships!"]]))
    vn.done()
@@ -431,7 +433,7 @@ end
 function biker4()
    vn.clear()
    vn.scene()
-   local biker = vn.newCharacter( _("Hyena Biker"), { npc4img } )
+   local biker = vn.newCharacter( _("Hyena Biker"), { image=npc4img } )
    vn.transition()
    biker(_([["Me and my buddies will show an incredible Hyena trick at this cycle's festival: two Hyenas fly side by side at full speed, then both pilots eject from their ship and enter the other one. I'm with the Stabbers Gang."]]))
    vn.done()
@@ -550,6 +552,10 @@ end
 
 -- Manage activities of gangs squadrons.
 function nextActivity( leader )
+   -- Gang died? Just ignore the stuff then
+   -- TODO maybe something fancier
+   if not leader:exists() then return end
+
    local mem = leader:memory()
    hook.rm( mem.MV_hook ) -- Clear hook
 
