@@ -11,7 +11,7 @@
    if system.cur():reputation("Dvaered") &lt; 0 or faction.reputationGlobal("Dvaered") &lt; 0 then
       return false
    end
-   --return require("misn_test").reweight_active() -- don't reweight for licenses
+   --return require("misn_test").reweight_active() -- don't reweight for licences
    return true
  </cond>
  <notes>
@@ -42,20 +42,20 @@ local vn       = require 'vn'
 local vntk     = require 'vntk'
 local dv       = require "common.dvaered"
 local pir      = require "common.pirate"
-
+local sfx = require "luaspfx.sfx"
 
 -- Define the cargo commodity
 local cargo_misn
 local function _cargo()
    if not cargo_misn then
-      cargo_misn = commodity.new( N_("Saboteurs"), N_("A group of saboteurs"), {gfx_space="person.webp"} )
+      cargo_misn = commodity.new( N_("Saboteurs"), N_("A group of saboteurs"), {gfx_space="person"} )
    end
    return cargo_misn
 end
 
-local agentPort = "dvaered/dv_military_m2.webp"
-local cyborPort = "neutral/male12.webp"
-local civilPort = "neutral/female2.webp"
+local agentPort = "dvaered/dv_military_m2"
+local cyborPort = "neutral/male12"
+local civilPort = "neutral/female2"
 
 local silent_taunts = { _("Poor lone little Llama!"),
                         _("I am the 'Silent Death'!"),
@@ -84,7 +84,7 @@ function create()
 
    if not misn.claim({mem.sharksys,mem.koalasys}) then misn.finish(false) end -- Claim
 
-   misn.setNPC( _("Dvaered Soldier"), agentPort, _("This Dvaered soldier may have a task for a private pilot") )
+   misn.setNPC( _("Dvaered Soldier"), agentPort, _("This Dvaered soldier may have a task for a private pilot.") )
 end
 
 function accept()
@@ -301,29 +301,29 @@ function land()
       vn.transition( )
       vn.na(_([[After landing, you notice Colonel Okran waiting for you on the dock.]]))
       local sol = vn.newCharacter( _("Colonel Okran"), { image=portrait.getFullPath(agentPort) } )
-      if diff.isApplied( "heavy_weapons_license" ) then
+      if diff.isApplied( "heavy_weapons_licence" ) then
          sol(fmt.f(_([["Hello again, citizen {name}. We have been informed by House Goddard of the tragic death of Mrs Grosjean. Lord Fatgun sent flowers to her family, and I believe you may have come to receive your reward. We will re-contact you in case we need your services again in the future."]]),
             {name=player.name()}))
       else
          sol(fmt.f(_([["Hello again, citizen {name}. We have been informed by House Goddard of the tragic death of Mrs Grosjean. Lord Fatgun sent flowers to her family, and I believe you may have come to receive your reward. We will re-contact you in case we need your services again in the future."
-"Oh, and as an additional reward, I made sure you can now purchase the Heavy Weapon License."]]),
+"Oh, and as an additional reward, I made sure you can now purchase the Heavy Weapon Licence."]]),
             {name=player.name()}))
          vn.sfxBingo()
-         vn.na(_([[You can now purchase the #bHeavy Weapon License#0.]]))
+         vn.na(_([[You can now purchase the #bHeavy Weapon Licence#0.]]))
       end
 
       vn.sfxVictory()
-      vn.na(fmt.f(_([[Colonel Okran pays you {credits}.]]), {credits=fmt.credits(mem.credits)}))
+      vn.na(fmt.f(_([[Colonel Okran pays you {credits}.]]), {credits="#g"..fmt.credits(mem.credits).."#0"}))
 
       vn.done()
       vn.run()
 
       faction.get("Dvaered"):hit(5)
-      if diff.isApplied( "heavy_weapons_license" ) then
+      if diff.isApplied( "heavy_weapons_licence" ) then
          dv.addStandardLog( _([[You performed a negotiation mission for Lord Fatgun, who needs to purchase a second Goddard battlecruiser. This mission consisted in killing a shareholder of Goddard who was opposed to this contract.]]) )
-      else -- Player does not have the license
-         dv.addStandardLog( _([[You performed a negotiation mission for Lord Fatgun, who needs to purchase a second Goddard battlecruiser. This mission consisted in killing a shareholder of Goddard who was opposed to this contract. Completing this mission has granted you access to the Heavy Weapon License.]]) )
-         diff.apply("heavy_weapons_license")
+      else -- Player does not have the licence
+         dv.addStandardLog( _([[You performed a negotiation mission for Lord Fatgun, who needs to purchase a second Goddard battlecruiser. This mission consisted in killing a shareholder of Goddard who was opposed to this contract. Completing this mission has granted you access to the Heavy Weapon Licence.]]) )
+         diff.apply("heavy_weapons_licence")
       end
       player.pay(mem.credits)
       misn.finish(true)
@@ -392,14 +392,28 @@ function spreadCommando()
    local vel = mem.koala:vel()
    local poC = mem.koala:pos() - vel/vel:mod() * 10
    mem.mrk = system.markerAdd( poC, _("Commandos") )
-   system.addGatherable( _cargo(), 1, poC, vel*0.5, 3600, true ) -- Spawn the commando (player-only gatherable) just behind the Koala
-   audio.soundPlay( "target" )
+   mem.commandosVelocity = vel*0.5
+   mem.commandosInitialPosition = poC
+   mem.commandosTimer = 0
+   system.addGatherable( _cargo(), 1, mem.commandosInitialPosition, mem.commandosVelocity, 3600, true ) -- Spawn the commando (player-only gatherable) just behind the Koala
+   hook.timer( 3, "updateMarkerPosition" )
+
+   sfx( false, nil, audiodata.new("snd/sounds/target") )
    player.msg("#o".._("Spacewalking commandos in sight.").."#0")
    player.autonavReset(5)
    mem.koala:setHilight(false)
    mem.gathHook = hook.gather("gather")
 end
 
+function updateMarkerPosition()
+   if mem.misn_state < 3 then
+      system.markerRm( mem.mrk )
+      mem.commandosTimer = mem.commandosTimer + 3
+      mem.mrk = system.markerAdd( mem.commandosInitialPosition + mem.commandosVelocity * mem.commandosTimer, _("Commandos") )
+      hook.timer( 3, "updateMarkerPosition" )
+   end
+end
+
 -- Player gathers the commandos
 function gather( comm, qtt )
    local cmisn = _cargo()
@@ -411,7 +425,7 @@ function gather( comm, qtt )
    hook.rm(mem.gathHook)
    pilot.cargoRm( player.pilot(), comm, qtt ) -- Remove standard cargo and add mission cargo
    mem.cid = misn.cargoAdd( cmisn, mem.mass )
-   audio.soundPlay( "afb_disengage" )
+   sfx( true, nil, audiodata.new("snd/sounds/afb_disengage") )
    player.msg( "#g".._("Commandos recovered.").."#0" )
    misn.osdActive(4)
    misn.markerMove( mem.misn_marker, mem.paypnt )
@@ -461,7 +475,7 @@ function sharkEscaped()
 end
 function sharkAttacked()
    hook.rm(mem.atkhook)
-   audio.soundPlay( "explosion0", mem.shark:pos(), mem.shark:vel() )
+   sfx( mem.shark:pos(), mem.shark:vel(), audiodata.new("snd/sounds/explosion0") )
    mem.shark:setSpeedLimit(50)
 end
 function sharkKilled()
