@@ -19,24 +19,26 @@ local zalek_outfits = eoutfits.merge{{
    "Za'lek Hunter Launcher", "Za'lek Reaper Launcher",
    "Grave Lance", "Orion Beam",
    -- Small Weapons
-   "Particle Beam", "Particle Lance",
+   "Particle Beam", "Particle Lance", "Orion Lance", "Electron Burst Cannon",
+   -- Point Defence
+   "ZIBS-16", "ZIBS-32",
    -- Utility
-   "Droid Repair Crew", "Milspec Scrambler",
-   "Targeting Array", "Agility Combat AI",
-   "Milspec Jammer", "Emergency Shield Booster",
-   "Weapons Ionizer", "Sensor Array",
+   "Droid Repair Crew", "Milspec Scrambler", "Unicorp Scrambler",
+   "Targeting Array", "Agility Combat AI", "Unicorp Jammer", "Hyperbolic Blink Engine",
+   "Milspec Jammer", "Emergency Shield Booster", "Weakness Harmonizer AI",
+   "Weapons Ionizer", "Sensor Array", "Sensor Array", "Flicker Drive",
    "Faraday Tempest Coating", "Hive Combat AI",
    -- Heavy Structural
    "Battery III", "Shield Capacitor III", "Shield Capacitor IV",
-   "Reactor Class III",
-   "Large Shield Booster",
+   "Reactor Class III", "Battery IV", "Auxiliary Processing Unit IV",
+   "Large Shield Booster", "Auxiliary Processing Unit III",
    -- Medium Structural
    "Battery II", "Shield Capacitor II", "Reactor Class II",
-   "Medium Shield Booster",
+   "Medium Shield Booster", "Auxiliary Processing Unit II",
    -- Small Structural
    "Improved Stabilizer", "Engine Reroute",
    "Battery I", "Shield Capacitor I", "Reactor Class I",
-   "Small Shield Booster",
+   "Small Shield Booster", "Auxiliary Processing Unit I",
 }}
 
 local zalek_params = {
@@ -54,29 +56,43 @@ local zalek_params = {
 local function choose_one( t ) return t[ rnd.rnd(1,#t) ] end
 local zalek_cores = {
    ["Za'lek Sting"] = function (_p) return {
-         choose_one{ "Milspec Orion 4801 Core System", "Milspec Thalos 4702 Core System" },
-         "Tricon Cyclone Engine",
-         choose_one{ "Nexus Medium Stealth Plating", "S&K Medium Combat Plating" },
+         systems = choose_one{ "Milspec Aegis 4701 Core System", "Milspec Thalos 4702 Core System" },
+         engines = choose_one{ "Tricon Cyclone Engine", "Nexus Arrow 700 Engine", "Melendez Buffalo Engine" },
+         hull = choose_one{ "Nexus Ghost Weave", "S&K Battle Plating" },
       } end,
    ["Za'lek Demon"] = function (_p) return {
-         choose_one{ "Milspec Orion 5501 Core System", "Milspec Thalos 5402 Core System" },
-         "Tricon Cyclone II Engine",
-         choose_one{ "Nexus Medium Stealth Plating", "S&K Medium-Heavy Combat Plating" },
+         systems = choose_one{ "Milspec Aegis 4701 Core System", "Milspec Thalos 4702 Core System" },
+         systems_secondary = choose_one{ "Milspec Aegis 4701 Core System", "Milspec Thalos 4702 Core System" },
+         engines = choose_one{ "Tricon Cyclone Engine", "Nexus Arrow 700 Engine", "Melendez Buffalo Engine" },
+         engines_secondary = choose_one{ "Tricon Cyclone Engine", "Nexus Arrow 700 Engine", "Melendez Buffalo Engine" },
+         hull = choose_one{ "Nexus Ghost Weave", "S&K Battle Plating" },
+         hull_secondary = "S&K Battle Plating",
       } end,
    ["Za'lek Mephisto"] = function (_p) return {
-         "Milspec Orion 9901 Core System",
-         choose_one{ "Unicorp Eagle 6500 Engine", "Tricon Typhoon II Engine" },
-         choose_one{ "Unicorp D-58 Heavy Plating", "Unicorp D-72 Heavy Plating" },
+         systems = choose_one{ "Milspec Aegis 8501 Core System", "Milspec Thalos 8502 Core System" },
+         systems_secondary = choose_one{ "Milspec Aegis 8501 Core System", "Milspec Thalos 8502 Core System" },
+         engines = choose_one{ "Nexus Bolt 3000 Engine", "Tricon Typhoon Engine" },
+         engines_secondary = choose_one{ "Nexus Bolt 3000 Engine", "Tricon Typhoon Engine" },
+         hull = "Unicorp D-58 Heavy Plating",
+         --hull_secondary = choose_one{ "Unicorp D-58 Heavy Plating", "Dummy Plating" },
+         hull_secondary = "Unicorp D-58 Heavy Plating",
       } end,
    ["Za'lek Diablo"] = function (_p) return {
-         "Milspec Thalos 9802 Core System",
-         choose_one{ "Unicorp D-58 Heavy Plating", "Unicorp D-72 Heavy Plating" },
-         choose_one{ "Tricon Typhoon II Engine", "Melendez Mammoth XL Engine" },
+         systems = choose_one{ "Milspec Aegis 8501 Core System", "Milspec Thalos 8502 Core System" },
+         systems_secondary = choose_one{ "Milspec Aegis 8501 Core System", "Milspec Thalos 8502 Core System" },
+         hull = "Unicorp D-58 Heavy Plating",
+         --hull_secondary = choose_one{ "Unicorp D-58 Heavy Plating", "Dummy Plating" },
+         hull_secondary = "Unicorp D-58 Heavy Plating",
+         engines = choose_one{ "Nexus Bolt 3000 Engine", "Melendez Mammoth Engine" },
+         engines_secondary = choose_one{ "Nexus Bolt 3000 Engine", "Melendez Mammoth Engine" },
       } end,
    ["Za'lek Hephaestus"] = function (_p) return {
-         "Milspec Thalos 9802 Core System",
-         choose_one{ "Unicorp D-72 Heavy Plating", "S&K Superheavy Combat Plating" },
-         "Melendez Mammoth XL Engine",
+         systems = choose_one{ "Milspec Aegis 8501 Core System", "Milspec Thalos 8502 Core System" },
+         systems_secondary = choose_one{ "Milspec Aegis 8501 Core System", "Milspec Thalos 8502 Core System" },
+         hull = choose_one{ "Unicorp D-58 Heavy Plating", "S&K War Plating" }, -- Ideally, should chose twice the same
+         hull_secondary = choose_one{ "Unicorp D-58 Heavy Plating", "S&K War Plating" },
+         engines = "Melendez Mammoth Engine",
+         engines_secondary = "Melendez Mammoth Engine",
       } end,
 }
 
